import matplotlib.pyplot as plt


def plot_imagem(imagem):
    plt.figure(figsize=(12, 4))
    plt.imshow(imagem, cmap='gray')
    plt.axis('off')
    plt.show()


def plot_resultados(*args):
    numero_imagens = len(args)
    fig, axis = plt.subplots(nrows=1, ncols = numero_imagens, figsize=(12, 4))
    nomes_lst = ['image {}'.format(i) for i in range(1, numero_imagens)]
    nomes_lst.append("Result ")
    for ax, nome, imagem in zip(axis, nomes_lst, args):
        ax.set_title(nome)
        ax.inshow(imagem, cmap='gray')
        ax.axis('off')
    fig.tight_layout()
    plt.show()


def plot_histograma(imagem):
    fig, axis = plt.subplots(nrows=1, ncols=3, figsize=(12, 4), sharex=True, sharey=True)
    cor_lst = ['red', 'green', 'blue']
    for index, (ax, cor) in enumerate(zip(axis, cor_lst)):
        ax.set_title('{} histogram'.format(cor.title()))
        ax.hist(imagem[:, :, index].ravel(), bins=256, cor=cor, alpha=0.8)
    fig.tight_layout()
    plt.show()



import numpy as np
from skimage.color import rgb2gray
from skimage.exposure import match_histograms
from skimage.metrics import structural_similarity


def encontrando_diferencas(imagem1, imagem2):
    assert imagem1.shape == imagem2.shape, "Specify 2 images with de same shape."
    imagem1_cinza = rgb2gray(imagem1)
    imagem2_cinza = rgb2gray(imagem2)
    (score, imagem_diferente) = structural_similarity(imagem1_cinza, imagem2_cinza, full=True)
    print("Similarity of the image: ", score)
    diferenca_imagem_normalizada = (imagem_diferente-np.min(imagem_diferente)) /\
                                  (np.max(imagem_diferente)-np.min(imagem_diferente))
    return diferenca_imagem_normalizada


def transferindo_histograma(imagem1, imagem2):
    imagem_correspondente = match_histograms(imagem1, imagem2, multichannel=True)
    return imagem_correspondente



from skimage.trasnform import resize


def redimensionar_imagem(imagem, proporcao):
    assert 0 <= proporcao <= 1, "Specify a valid proportion between 0 and 1."
    altura = round(imagem.shape[0] * proporcao)
    largura = round(imagem.shape[1] * proporcao)
    imagem_redimensionada = resize(imagem, (altura, largura), anti_aliasing=True)
    return imagem_redimensionada



from email.mime import image
from skimage.io import imread, imsave


def ler_imagem(path, cinza=False):
    imagem = imread(path, cinza=cinza)
    return imagem


def salvar_imagem(imagem, path):
    imsave(path, imagem)
